Modulatory Signals
==================

.. _ModulatorySignal_Subtypes:

.. toctree::
   :maxdepth: 1

   LearningSignal
   ControlSignal
   GatingSignal

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.ports.modulatorysignals.modulatorysignal
   :members:
   :exclude-members: random, update, Parameters

